==> aliyun-java-sdk-live-2.6.0-sources.jar: com/aliyuncs/live/model/v20161101/DescribeLiveStreamsControlHistoryResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.aliyuncs.live.model.v20161101;

import java.util.List;
import com.aliyuncs.AcsResponse;
import com.aliyuncs.live.transform.v20161101.DescribeLiveStreamsControlHistoryResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class DescribeLiveStreamsControlHistoryResponse extends AcsResponse {

	private String requestId;

	private List<LiveStreamControlInfo> controlInfo;

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public List<LiveStreamControlInfo> getControlInfo() {
		return this.controlInfo;
	}

	public void setControlInfo(List<LiveStreamControlInfo> controlInfo) {
		this.controlInfo = controlInfo;
	}

	public static class LiveStreamControlInfo {

		private String streamName;

		private String clientIP;

		private String action;

		private String timeStamp;

		public String getStreamName() {
			return this.streamName;
		}

		public void setStreamName(String streamName) {
			this.streamName = streamName;
		}

		public String getClientIP() {
			return this.clientIP;
		}

		public void setClientIP(String clientIP) {
			this.clientIP = clientIP;
		}

		public String getAction() {
			return this.action;
		}

		public void setAction(String action) {
			this.action = action;
		}

		public String getTimeStamp() {
			return this.timeStamp;
		}

		public void setTimeStamp(String timeStamp) {
			this.timeStamp = timeStamp;
		}
	}

	@Override
	public DescribeLiveStreamsControlHistoryResponse getInstance(UnmarshallerContext context) {
		return	DescribeLiveStreamsControlHistoryResponseUnmarshaller.unmarshall(this, context);
	}
}

==> aliyun-java-sdk-live-3.8.0-sources.jar: com/aliyuncs/live/model/v20161101/DescribeLiveStreamsControlHistoryResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.live.model.v20161101;

import java.util.List;
import com.aliyuncs.AcsResponse;
import com.aliyuncs.live.transform.v20161101.DescribeLiveStreamsControlHistoryResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class DescribeLiveStreamsControlHistoryResponse extends AcsResponse {

	private String requestId;

	private List<LiveStreamControlInfo> controlInfo;

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public List<LiveStreamControlInfo> getControlInfo() {
		return this.controlInfo;
	}

	public void setControlInfo(List<LiveStreamControlInfo> controlInfo) {
		this.controlInfo = controlInfo;
	}

	public static class LiveStreamControlInfo {

		private String streamName;

		private String clientIP;

		private String action;

		private String timeStamp;

		public String getStreamName() {
			return this.streamName;
		}

		public void setStreamName(String streamName) {
			this.streamName = streamName;
		}

		public String getClientIP() {
			return this.clientIP;
		}

		public void setClientIP(String clientIP) {
			this.clientIP = clientIP;
		}

		public String getBizAction() {
			return this.action;
		}

		public void setBizAction(String action) {
			this.action = action;
		}

		/**
		 * @deprecated use getBizAction instead of this.
		 */
		@Deprecated
		public String getAction() {
			return this.action;
		}

		/**
		 * @deprecated use setBizAction instead of this.
		 */
		@Deprecated
		public void setAction(String action) {
			this.action = action;
		}

		public String getTimeStamp() {
			return this.timeStamp;
		}

		public void setTimeStamp(String timeStamp) {
			this.timeStamp = timeStamp;
		}
	}

	@Override
	public DescribeLiveStreamsControlHistoryResponse getInstance(UnmarshallerContext context) {
		return	DescribeLiveStreamsControlHistoryResponseUnmarshaller.unmarshall(this, context);
	}
}
